@@ -1,14 +1,22 @@
-get.peaks<-function(data,channel,trials=NULL,trial.cn="Trial",time.cn="Time"){
+get.peaks<-function(data,channel,trials=NULL,
+trial.cn="Trial",time.cn="Time",add.lines=NULL,...)
+{
 	if(is.null(trials)){
 		trials<-sort(unique(data[,trial.cn]))
-	}
+	}		
 	xy<-list()
 	for(tr in trials){
 		cat("fetching peaks for trial",tr,"...\n")
 		tmp<-data[data[,trial.cn]==tr,]
 		plot(tmp[,time.cn],tmp[,channel],type="l",main=paste("Trial",tr),
-			xlab="Time",ylab="Amplitude")
-		xy.tmp<-locator()
+			xlab="Time",ylab="Amplitude",...)
+		if(!is.null(add.lines)){
+			for(al in 1:length(add.lines)){
+				lines(tmp[,time.cn],tmp[,add.lines[[al]][1]],
+					col=add.lines[[al]][2],...)
+			}
+		}
+		xy.tmp<-locator(...)
 		if(!is.null(xy.tmp)){
 		time<-tmp[,time.cn]
 		MYTIME<-vector("numeric")
